@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::YANICK::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Dist::Zilla::PluginBundle::YANICK::VERSION = '0.4.3';
+  $Dist::Zilla::PluginBundle::YANICK::VERSION = '0.5.0';
 }
 
 # ABSTRACT: Be like Yanick when you build your dists
@@ -26,7 +26,7 @@ use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::MetaProvides::Package;
 use Dist::Zilla::Plugin::InstallRelease;
 use Dist::Zilla::Plugin::InstallGuide;
-use Dist::Zilla::Plugin::Twitter;
+use Dist::Zilla::Plugin::Twitter 0.013;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -72,13 +72,14 @@ sub configure {
           TestRelease
           ConfirmRelease
           Git::Check
-          Git::Commit
           /,
         [ 'Git::CommitBuild' => { release_branch => $release_branch } ],
         [ 'Git::Tag'  => { tag_format => 'v%v', branch => $release_branch } ],
     );
 
+    # Git::Commit can't be before Git::CommitBuild :-/
     $self->add_plugins(qw/
+        Git::Commit
         Author::YANICK::NextSemanticVersion
     /);
 
@@ -110,7 +111,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.4.3
+version 0.5.0
 
 =head1 DESCRIPTION
 
